@@ -1,3 +1,4 @@
+from ipaddress import ip_address, IPv4Network
 import socket
 import subprocess
 import sys
@@ -36,8 +37,8 @@ def is_valid_ip(ip: str) -> bool:
     if len(parts) == 4:
         for p in parts:
             try:
-                if 0 <= int(p) <= 255:
-                    continue
+                if not (0 <= int(p) <= 255):
+                    return False
             except ValueError:
                 return False
 
@@ -52,6 +53,13 @@ def is_valid_ip(ip: str) -> bool:
     return False
 
 
+def is_ip_in_network(ip: str, network: IPv4Network) -> bool:
+    if not is_valid_ip(ip):
+        return False
+
+    return ip_address(ip) in network
+
+
 def is_valid_email(email: str) -> bool:
     parts = email.split("@")
     if len(parts) == 2:
