@@ -1,7 +1,7 @@
 import logging
 import os
 import time
-from typing import Optional
+from typing import Optional, Iterable
 
 # noinspection PyProtectedMember
 from azure.core.exceptions import ServiceRequestError, DecodeError, \
@@ -112,7 +112,12 @@ class TransportAzure(Transport):
 
         key = self.normalize(path)
         blob_client = self.service_client.get_blob_client(self.blob_container, key)
-        self.with_retries(blob_client.delete_blob)
+        try:
+            self.with_retries(blob_client.delete_blob)
+        except TransportException as error:
+            # If its already not found, then consider it deleted.
+            if not isinstance(error.cause, ResourceNotFoundError):
+                raise
 
     def exists(self, path):
         key = self.normalize(path)
@@ -183,3 +188,7 @@ class TransportAzure(Transport):
             except TransportException as error:
                 if not isinstance(error.cause, ResourceExistsError):
                     raise
+
+    def list(self, prefix: Optional[str] = None) -> Iterable[str]:
+        for blob in self.container_client.list_blobs(name_starts_with=prefix):
+            yield blob['name']
